def add_numbers(a: int, b: int) -> int:
    return a + b


def subtract_numbers(a, b):
    return a - b
